==> pegasus-merchandise-api-1.4.21-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSkuQualifyCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

public class PcsSkuQualifyCond extends BaseQueryCond implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
    private Long id;
	private String skuCode;
    private Integer auditStatus;
    private Integer riskLevel;
    private String riskDesc;
    private Long creator;
    private Long lastModifier;
    private Date createTimeStart;
    private Date createTimeEnd;
    private Date modifyTimeStart;
    private Date modifyTimeEnd;
    private Integer isPostMeeting;
    private Integer flowTrend;

    public Long getId() { return id; }

    public void setId(Long id) { this.id = id; }

    public String getSkuCode() {
		return skuCode;
	}


	public void setSkuCode(String skuCode) {
		this.skuCode = skuCode;
	}


	public Integer getAuditStatus() {
		return auditStatus;
	}


	public void setAuditStatus(Integer auditStatus) {
		this.auditStatus = auditStatus;
	}


	public Integer getRiskLevel() {
		return riskLevel;
	}


	public void setRiskLevel(Integer riskLevel) {
		this.riskLevel = riskLevel;
	}


	public String getRiskDesc() {
		return riskDesc;
	}


	public void setRiskDesc(String riskDesc) {
		this.riskDesc = riskDesc;
	}


	public Long getCreator() {
		return creator;
	}

	public void setCreator(Long creator) {
		this.creator = creator;
	}

	public Long getLastModifier() {
		return lastModifier;
	}

	public void setLastModifier(Long lastModifier) {
		this.lastModifier = lastModifier;
	}

	public Date getCreateTimeStart() {
		return createTimeStart;
	}

	public void setCreateTimeStart(Date createTimeStart) {
		this.createTimeStart = createTimeStart;
	}


	public Date getCreateTimeEnd() {
		return createTimeEnd;
	}


	public void setCreateTimeEnd(Date createTimeEnd) {
		this.createTimeEnd = createTimeEnd;
	}


	public Date getModifyTimeStart() {
		return modifyTimeStart;
	}


	public void setModifyTimeStart(Date modifyTimeStart) {
		this.modifyTimeStart = modifyTimeStart;
	}


	public Date getModifyTimeEnd() {
		return modifyTimeEnd;
	}


	public void setModifyTimeEnd(Date modifyTimeEnd) {
		this.modifyTimeEnd = modifyTimeEnd;
	}

	public Integer getIsPostMeeting() {
		return isPostMeeting;
	}


	public void setIsPostMeeting(Integer isPostMeeting) {
		this.isPostMeeting = isPostMeeting;
	}

	public Integer getFlowTrend() {
		return flowTrend;
	}

	public void setFlowTrend(Integer flowTrend) {
		this.flowTrend = flowTrend;
	}


	//constructor
    public PcsSkuQualifyCond() {
        super();
    }

}

==> pegasus-merchandise-api-3.2.0-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSkuQualifyCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;


import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

public class PcsSkuQualifyCond extends BaseQueryCond implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
    private Long id;
	private String skuCode;
    private Integer auditStatus;
    private Integer riskLevel;
    private String riskDesc;
    private Long creator;
    private Long lastModifier;
    private Date createTimeStart;
    private Date createTimeEnd;
    private Date modifyTimeStart;
    private Date modifyTimeEnd;
    private Integer isPostMeeting;
    private Integer flowTrend;

    public Long getId() { return id; }

    public void setId(Long id) { this.id = id; }

    public String getSkuCode() {
		return skuCode;
	}


	public void setSkuCode(String skuCode) {
		this.skuCode = skuCode;
	}


	public Integer getAuditStatus() {
		return auditStatus;
	}


	public void setAuditStatus(Integer auditStatus) {
		this.auditStatus = auditStatus;
	}


	public Integer getRiskLevel() {
		return riskLevel;
	}


	public void setRiskLevel(Integer riskLevel) {
		this.riskLevel = riskLevel;
	}


	public String getRiskDesc() {
		return riskDesc;
	}


	public void setRiskDesc(String riskDesc) {
		this.riskDesc = riskDesc;
	}


	public Long getCreator() {
		return creator;
	}

	public void setCreator(Long creator) {
		this.creator = creator;
	}

	public Long getLastModifier() {
		return lastModifier;
	}

	public void setLastModifier(Long lastModifier) {
		this.lastModifier = lastModifier;
	}

	public Date getCreateTimeStart() {
		return createTimeStart;
	}

	public void setCreateTimeStart(Date createTimeStart) {
		this.createTimeStart = createTimeStart;
	}


	public Date getCreateTimeEnd() {
		return createTimeEnd;
	}


	public void setCreateTimeEnd(Date createTimeEnd) {
		this.createTimeEnd = createTimeEnd;
	}


	public Date getModifyTimeStart() {
		return modifyTimeStart;
	}


	public void setModifyTimeStart(Date modifyTimeStart) {
		this.modifyTimeStart = modifyTimeStart;
	}


	public Date getModifyTimeEnd() {
		return modifyTimeEnd;
	}


	public void setModifyTimeEnd(Date modifyTimeEnd) {
		this.modifyTimeEnd = modifyTimeEnd;
	}

	public Integer getIsPostMeeting() {
		return isPostMeeting;
	}


	public void setIsPostMeeting(Integer isPostMeeting) {
		this.isPostMeeting = isPostMeeting;
	}

	public Integer getFlowTrend() {
		return flowTrend;
	}

	public void setFlowTrend(Integer flowTrend) {
		this.flowTrend = flowTrend;
	}


	//constructor
    public PcsSkuQualifyCond() {
        super();
    }

}
